Seznam – najdu tam, co neznám
Description: Nejnavštěvovanější český internetový portál nabízející vyhledávač, e-mail, aktuální zprávy, předpověď počasí a odkazy, které se mohou hodit.

#

Hledej v internetu:

###### Hlavní obsah

## Seznam Zprávy • úterý 21. března. Svátek má Radek.

### Byl jsem ve fatální životní situaci, říká Železný o incidentu se strážníkem

S městskou policií mám špatnou zkušenost a video je sestříhané, ale měl jsem se chovat lépe, říká moderátor České televize Jakub Železný k incidentu se strážníkem městské policie.

### Na trhu s ruskou ropou se objevili tajemní hráči

### Dnešní mladí budou žít déle, čas v penzi se jim přesto zkrátí

### Čína nemůže plně podpořit Ukrajinu. „Putinův pád je pro ni nejhorší scénář“

## Novinky

### Oděsa čelila masivnímu ruskému náletu

Oděsa čelila v úterý večer masivnímu ruskému náletu. První informace hovoří o značných škodách, mrtvých a zraněných, píše server Ukrajinska pravda a agentura Unian.

### Zelenskyj vyzývá Čínu, aby se přidala k ukrajinskému mírovému plánu

### Útočníci zbili na ulici v Praze muže. Zásahovka jim rozbila mercedes

### Nemocnicemi v USA se šíří nebezpečná houba. Hostitele kolonizuje

### Skupinový sex, divoké orgie a mrtvola v prádelním koši. V hlavě vraha se po letech zrodil nepochopitelný plán

### Kdy dělat kompromisy ve vztahu a kdy už ne

### Příspěvek na stavební spoření zrušíme, u běžících smluv snížíme na půlku, shodla se vláda

### Pekarová Adamová povede rekordní podnikatelskou misi na Tchaj-wan

## Super

### Máš to v topu, ukaž to! Tereza Ramba zavzpomínala, jak jí manžel povolil vytasit poprsí na kameru

Tereza Ramba (33) patří k našim nejobsazovanějším herečkám. Co se nahoty týče, vždy se držela zpátky a zastávala názor, že vysvléct se před kamerou není potřeba. Velká změna přišla s filmem Betlémské světlo.

### Filmový Thor Chris Hemsworth a jeho manželka se stali terčem kritiky kvůli narozeninové fotce syna

### Luxusní svatba na Pražském hradě: Slavná česká burleska se vdala s korunou na hlavě, předtím si nechala odstranit silikony

## Sport

### HOKEJ ONLINE: Přestřelka pokračuje, drama vrcholí! Vítkovice skolily Kometu

Hokejisté Pardubic budou v dnešním pokračování čtvrtfinále play off extraligy usilovat na ledě Olomouce po dvou domácích výhrách o postupový mečbol (průběžný stav je 4:4, prodlužuje se). V souběžně hrané sérii mezi Brnem a Vítkovicemi se sice Brňané dostali záhy do vedení, ale nakonec zvítězili hosté 4:1 a ujali se vedení 2:1 na zápasy. Utkání bylo kvůli nezpůsobilé hrací ploše v 15. minutě úvodní třetiny přerušeno a zhruba hodinu se nehrálo. Oba duely můžete sledovat v podrobných online reportážích na Sport.cz.

### Kanár a rychlý konec české komety. Po skreči končí v Miami i Siniaková

### Díry v ledu? Kluby šetří na chlazení, myslí si expert ČT

### Krejčíková utřela Medveděva. Rus mluvil o toxickém vztahu

## Stream

### Mezinárodní ostuda. Největší spáč české politiky vytuhl i v živém přenosu na světovém fóru Stream originals

Není pochyb o tom, že politika je náročná a vyčerpávající disciplína. A když se jedná o zdlouhavou konferenci s monotónními projevy, přímo to vybízí k

### Petr Švancara se opřel do Novotného a Survivoru: Kvůli genderovému pravidlu si nebral servítky Extra Host

### Nejkrásnější česká herečka 80. let prošla peklem. Sesypala se a bulvár ji téměř zničil. V 76 letech bojuje jako lvice Stream originals

### Tereza Ramba už se nebojí ukázat se nahá před kamerou Super

## Proženy

### Česká kosmetika, na kterou nedají dopustit známé tváře: Co používá Hana Vagnerová či Adéla Elbel

Říkáte si, jak dobře některé slavné ženy vypadají a jaké tajemství je za jejich půvabem… Jsou to dobré geny, nebo kosmetika? To asi nerozsoudíme. V každém případě musejí o pleť pečovat pravidelně – v jejich povolání je požadován téměř dokonalý vzhled. Mrkněte, jaké přípravky používají oblíbené české herečky.

### Jaký jste kov podle alchymistického horoskopu a co to znamená? Cín je paličatý, rtuť vnímavá

### Týdenní horoskop: Blíženci si zvládnou každého podmanit, Váhy by si měly dát pozor na konflikty

### Dvacet let od premiéry Pirátů z Karibiku: Kdo si prošel peklem a kdo se snaží vymanit ze škatulky

## Garáž

### Jízdní řád Škody: Na podzim nový Superb a Kodiaq, v lednu 2024 faceliftovaná Octavia

Škoda Auto v rámci výroční tiskové konference neřešila jenom ekonomické výsledky, ale upřesnila i své plány stran nových modelů. Stěžejní jsou letos nové generace těch největších - Superbu i Kodiaqu. Pracuje se i na omlazené Octavii. Ta se představí začátkem příštího roku.

### Češi pomalu ztrácí chuť na naftu. Kdo má živnost, chce benzin, ukazuje analýza

### Dacia Jogger po faceliftu: Benzin má víc síly než plyn

###### Automaticky nekonečně načítané články

Následují automaticky nekonečně načítané články. Zde je můžete přeskočit.

- ##
  Refresher

  ### Do roku 2100 vznikne Rakousko-Slovensko a zabere část Moravy. Takto vypadá předpověď umělé inteligence o budoucnosti Evropy

  Před 8 hodinami
  Umělá inteligence předpovídá, jak bude za necelých 80 let vypadat mapa Evropy.

- ##
  FinTag

  ### Komentář: Hanba Vám, prezidente Pavle…

  Před 14 hodinami
  Nedávno inaugurovaný prezident Petr Pavel nebude jezdit ve speciálně upraveném voze Škoda Superb, kterým se čeští prezidenti vozí od roku 2003, ale ve speciálně upraveném voze BMW řady 7.

- ##
  Refresher

  ### Do roku 2100 vznikne Rakousko-Slovensko a zabere část Moravy. Takto vypadá předpověď umělé inteligence o budoucnosti Evropy

  Před 8 hodinami
  Umělá inteligence předpovídá, jak bude za necelých 80 let vypadat mapa Evropy.

- ##
  WN24

  ### Tři muži se na ulici v Londýně střídali ve znásilňování ženy přímo před kamerou

  Před 2 hodinami
  Strašlivý útok na mladou ženu byl spáchán v ulicích Londýna. Tři muže zachytila CCTV kamera, jak ženu jeden po druhém znásilňují. Nyní byli pachatelé odsouzeni vrchním soudem ve Snaresbooku.

- ##
  Česká justice

  ### Mexiko opakovaně nevpustilo Čechy na své území

  Před 15 hodinami
  Případy nevpuštění českých občanů na území Mexika, jejich detence a následné deportace se množí. A to i přesto, že přijedou s cestovní kanceláří nebo prokáží program a prostředky na pobyt. Stížnost na nečinnost českého konzulárního oddělení řešil i zástupce ombudsmana Vít Schorm.

- ##
  Káčin zvěřinec

  ### Kočka a obří tarantule

  Před 8 roky •
  111112 zhlédnutí
  V dnešním díle uvidíte zvířátka, která si umí roztomile hrát. Zavítáme do čínské ZOO za pandami, které se nemohou nabažit klouzačky, uslyšíte hrajícího a zpívajícího pejska, a uvidíte kočku, jejíž nejoblíbenější hračkou je obrovský pavouk.Účinkovala: Kateřina Hrachovcová HerčíkováStřih: Jirka NovákProdukce: Lucka DřízhalováŠéfproducent: Lukáš Záhoř© 2014 Seznam.cz, a.s.

- ##
  Bety

  ### Sexuální polohy pro současnou stimulaci bodu G a klitorisu

  Před 2 hodinami
  Kdo by nestál o orgasmus, tu vysoce intenzivní fyzickou rozkoš, kterou kontroluje autonomní nervový systém? Pokud toužíte po jeho dvojité porci, vsaďte na tyhle sexuální polohy, při kterých dochází ke stimulaci bodu G a klitorisu – současně!

- ##
  Kupi Magazín

  ### Billa zvyšuje od dubna mzdy svým zaměstnancům. Jakou výplatu mají pokladní v Kauflandu, Lidlu nebo v Penny?

  Před 1 dnem
  Řetězec BILLA oznámil, že od dubna navýší mzdy všem svým zaměstnancům v průměru o 7 %. To znamená roční nárůst přes 200 milionů Kč, které společnost investuje navíc. Před měsícem přitom o zvýšení platů pro své zaměstnance informovali také Lidl, Kaufland nebo Penny Market. Kolik si nově vydělá pokladní v těchto supermarketech?

- ##
  Zdravé Zprávy

  ### Ukrajinská mládež často rezignuje na českou střední školu

  Před 6 hodinami
  Zhruba čtyři a půl tisíce uprchlíků z Ukrajiny ve věku 15 až devatenáct let pobývajících v Česku nestuduje střední školu. Část z nich chce školu dokončit na Ukrajině na dálku. Letos se v ČR na střední školu přihlásilo dva a půl tisíce Ukrajinců.

- ##
  Kupi Magazín

  ### IKEA stahuje z prodeje hračku pro děti. Varuje před používáním a vrátí vám za ni peníze

  Před 10 hodinami
  Společnost IKEA vyzývá všechny zákazníky před hračkou, která má rozvíjet motorické schopnosti dětí, aby ji přestali používat, kontaktovali společnost IKEA a zažádali o vrácení peněz v plné výši.

- ##
  Tisíce lidí zajímá...

  ### Medvědí česnek

  Před 6 roky •
  244861 zhlédnutí
  Medvědí česnek pomáhá proti nachlazení, zabraňuje nadýmání, čistí krev, likviduje plísně a bakterie v organismu a je přírodním antibiotikem. Začíná růst na jaře a jeho listy se dají sbírat od začátku dubna až do konce června. Aby neztratil svou chuť a vitamíny, je vhodné ho přidávat až do hotových jídel, pomazánek, salátů či polévek. Aby vám česnek medvědí nejdéle vydržel, odborníci doporučují listy nasekat a nechat zamrazit. Můžete si však vyrobit i chutné pesto, které v lednici vydrží i pár týdnů.

- ##
  TN

  ### Biden rozhodl o odtajnění informací o původu koronaviru. Čína se bouří

  Před 9 hodinami
  Mezi Čínou a USA to zase vře. Americký prezident Joe Biden totiž podepsal zákon, který nařizuje odtajnění informací o původu koronaviru. Čína je ale výrazně proti. Podle země totiž informace zkreslují skutečnost.

- ##
  CNN Prima News

  ### Vydrží v Česku oteplení, nebo se vrátí zima? Meteorologové vydali předpověď na měsíc

  Před 1 dnem
  V nadcházejících týdnech bude podle Českého hydrometeorologického ústavu (ČHMÚ) v Česku vládnout téměř jarní počasí. Denní maxima budou v průměru okolo 15 stupňů. Srážek se čeká více až v půlce dubna.

- ##
  Dřevostavitel

  ### Jaromír si poradil se stavebním úřadem a vyzrál i nad územním plánem

  Před 14 hodinami
  Jak si šikovně poradil s nevyhovujícím územním plánem a proč by se podle něj člověk při stavbě neměl hádat o každou korunu? Prohlédněte si jeho dům u Brna.

- ##
  CNN Prima News

  ### Svíčky, obrázky a těžké chvíle v Olomouci: Adámek zemřel, musela druháčkům říct učitelka

  Před 10 hodinami
  Tragická smrt talentovaného devítiletého hokejisty Adama Koutného zasáhla nejen jeho rodinu a přátele, ale také Základní školu Olomouc, kterou navštěvoval. Žákům 2. A musela tuto smutnou zprávu v pondělí oznámit jejich třídní učitelka. Před budovou školy i v samotné třídě, kam chlapec chodil, vzniklo pietní místo.

- ##
  Novinky

  ### Připojení fotovoltaiky do sítě se komplikuje, distributor dokonce vydal mapu připojitelnosti

  Před 11 hodinami
  Zájem o instalaci fotovoltaiky má čím dál více Čechů. Počet žádostí o připojení vlastních solárů k dodávkám do sítě se ovšem v posledních letech zvýšil natolik, že to provozovatelům distribuční sítě dělá nemalé problémy. S těmi se potýkají zejména na Moravě a ve Slezsku, kde je síť v některých oblastech tak napjatá, že ne všechny domácnosti s fotovoltaikou mají možnost posílat přebytky do sítě. Distributoři to řeší miliardovými investicemi, které by měly situaci časem zlepšit.

- ##
  Aktuálně

  ### V Evropě vzniká bumerang proti "zelené" politice. Nizozemští farmáři vyhráli volby

  Před 8 hodinami
  Nizozemskou vládu porazili v krajských volbách farmáři, kteří odmítají tlak na snižování emisí v EU.

- ##
  Mistři volantu

  ### Dodávka si dává zběsilý slalom mezi kamiony a ještě k tomu na ledu

  Před 4 roky •
  313824 zhlédnutí
  Zubr přes cestu. Řidič dodávky, který si zřejmě myslí, že je Ester Ledecká, a trhá rekordy v divokém slalomu mezi kamiony. A na závěr šťastlivec století, na nějž se řítil splašený kamion ve smyku, a on stejně vyvázl bez škrábance.

- ##
  Dům financí

  ### Poradna: Jak vysoký je průměrný důchod na Slovensku?

  Před 1 dnem
  Adéla: Pracovala jsem několik let i na Slovensku, zajímalo by mě proto, jak vysoký je průměrný důchod na Slovensku. Jak vychází porovnání s Českem, kde jsem pracovala více let.

- ##
  Olomoucký deník

  ### V Šantovce se volila Miss, krásky předvedly i plavky od Nely Slovákové

  Před 1 dnem
  Novou královnu krásy vybrali porotci během víkendového galaprogramu v olomouckém obchodním centru Šantovka. V nedělním finále se o korunku utkalo celkem deset dívek, které postoupily z dvacítky sobotních semifinalistek.

- ##
  Kinotip2

  ### Vojtěch Machuta dočasně odchází z Ulice. Bude dohlížet na výcvik pilotů

  Před 6 hodinami
  Adam Volák se teď se zlomeným srdcem chystá odletět na prestižní stáž. V Praze zanechává nešťastnou Jarku. Jeho zmizení ze seriálu bylo pro herce Vojtěcha Machutu nutné. Bude totiž plánovat výcvik pilotů. Do Ulice se časem zase vrátí.

- ##
  Prima Ženy

  ### Tereza Ramba už se nestydí svlékat ve filmu. Někdy jsou kozy důležitější, říká

  Před 10 hodinami
  Tereza Ramba (33) se stala úspěšnou herečkou, přesto velkou část své kariéry měla na talíři to, že se hned ve svém prvním filmu odhalila. Nadále v tom nechtěla pokračovat a svlékat se pro ni bylo tabu, nyní si to ale rozmyslela a je nadšená. Proč tomu tak je a co je důvodem rozepří mezi ní a manželem, prozradila v oblíbené talk show.

- ##
  Echo24

  ### VIDEO: Ukrajinci použili „kamikaze“ vozítka. Na tanky Rusů útočí dálkově

  Před 7 hodinami
  Válka na Ukrajině dala mnohým bojovníkům příležitost vyzkoušet nekonvenční zbraně a technologie. Na telegramu koluje video dálkově ovládaného bezpilotního pozemního vozidla, vybaveného výbušninami. Ukrajinské síly ho využívají k likvidaci ruských pozic.

- ##
  Deník N

  ### Mynář se podruhé pokoušel vrátit dotaci, kvůli které ho stíhá policie. Neuspěl, kladl si podmínky

  Před 1 dnem
  Ministerstvo pro místní rozvoj podle zjištění Deníku N už podruhé odmítlo žádost někdejšího kancléře Vratislava Mynáře, který chtěl vrátit šestimilionovou dotaci na dostavbu penzionu v Osvětimanech. Vrácení dotace by pro Mynáře mohlo znamenat polehčující okolnost v kauze, v níž je od jara 2021 trestně stíhaný a v níž exprezident Zeman neúspěšně žádal premiéra Petra Fialu (ODS) o spolupodpis abolice.

- ##
  Svět Ženy

  ### Kvíz: Gott, Bartošová, ale i královna bulváru Hanychová či oblíbená Ewa Farna aneb Jak dobře se vyznáte v životech českých celebrit

  Před 9 hodinami
  Mohlo by se zdát, že Česká republika není příliš velká, ovšem slavnými, anebo těmi, kteří se chtějí stát populárními, se to tady jenom hemží. Pravdou zůstává, že se bulvární média těší v Česku velké oblibě a my si prostě nemůžeme občas pomoct a kliknete na poutavý titulek. V našem kvízu si můžete svoje znalosti rovnou otestovat!

- ##
  CNN Prima News

  ### Český hokejista stihl 51 bodů za pět zápasů a byl větší hit než božský McDavid. Šílené, říká

  Před 16 hodinami
  Jak se dostat do společnosti zřejmě nejlepšího hokejisty současnosti Connora McDavida? Český útočník Marek Malinský našel cestu, a to ani nemusel vyrazit do zámoří. Aby mohl skloubit studia, podnikání a sport, vzal před sezonou nabídku z CSKA Sofia. Bulharské angažmá opouštěl s 51 body v pěti zápasech základní části ligy. „Vypadá to bláznivě, až šíleně,“ přiznává pro CNN Prima NEWS hráč, který byl díky svému počinu v jednu chvíli nevyhledávanějším hráčem na světě.

- ##
  Poznat svět

  ### Moře v USA vyplavilo prehistorickou rybu. V oceánech se udržela 120 milionů let

  Před 3 dny
  Historie je tu stále s námi, nemůžeme za ní jen tak jednoduše zavřít dveře. Nedávným důkazem bylo pozorování ryby, jejíž předkové žili již v mezolitu, u východních břehů Spojených států.

- ##
  Dům a zahrada

  ### Použijte při praní ocet a těšte se na dokonale čisté prádlo

  Před 22 hodinami
  Máte dost chemických prostředků na praní a chtěli byste pro změnu zkusit přírodní cestu? Vyzkoušejte účinný a levný ocet, který má schopnost rozjasnit, změkčit, vydezinfikovat a odstranit zápach z vašeho prádla.

- ##
  TopRecepty

  ### Drážďanský pudinkový koláč Eierschecke má nadýchaný korpus a dvojitou náplň z tvarohu a pudinku. Díky tomu chutná božsky!

  Před 14 hodinami
  Koláč Eierschecke na první pohled tak trochu připomíná cheesecake nebo jeho německou obdobu Käsekuchen. Tvaroh se do něj ostatně i přidává, kromě toho ale rovněž i spousta vajíček, které koláči dodávají vláčnou pudinkovou chuť a celý dezert se díky tomu úžasně rozplývá na jazyku.

- ##
  Novinky.cz: Krimi

  ### Útočníci zbili na ulici v Praze muže. Zásahovka jim rozbila mercedes

  Před 7 hodinami •
  43028 zhlédnutí
  Zásahová jednotka zadržela dva agresivní útočníky, kteří na začátku března v Praze přepadli muže na ulici. Způsobili mu bodná poranění a utekli. Jeden je stíhán vazebně.

- ##
  Ruik

  ### To by byla bomba! V souvislosti s Crystalem Palace padlo jméno Jindřicha Trpišovského

  Před 15 hodinami
  V pátek během ranních hodin byl odvolán trenér Crystalu Palace Patrick Vieira. Následně hráči Eagles nezvládli londýnské derby na půdě Arsenalu. Otázkou je, kdo na lavičku usedne nyní. V talkshow Premier Club padlo také jméno Jindřicha Trpišovského.

- ##
  Svět

  ### Putinovy neklidné nohy. Záběry s čínským prezidentem živí spekulace o nemoci

  Před 9 hodinami •
  72262 zhlédnutí
  Záběry ze schůzky Vladimira Putina s čínským prezidentem Si Ťin-pchingem v Kremlu opět rozvířily spekulace, které má za podložené například ukrajinská tajná služba. Že ruského vůdce zrazuje zdraví.

- ##
  Kdo to je?

  ### Už to zabal! Jsi stará a ošklivá! Nadávají zpěvačce, které je oblečení a celibát uplně cizí

  Před 1 rokem •
  292043 zhlédnutí
  Poznáte ikonu, která se nestydí už několik dekád?

- ##
  Káčin zvěřinec

  ### Obrovský sumec je úlovkem snů

  Před 6 roky •
  79340 zhlédnutí
  Není to zrovna krasavec, ale pyšní se tím, že je největší evropskou rybou. Můžete ho chovat i doma, třeba jako malé sumečky v akváriu, ale tahle ryba má pořád hlad! Ulovit sumce není legrace, tak se podívejte, jak vypadá opravdu obří úlovek!Účinkovala: KAIRA K. HrachovcováStřih: Christián PyrinecKamera: Petr ŠtulířProdukce: Lucka DřízhalováŠéfproducent: Lukáš Záhoř© 2016 Seznam.cz, a.s

- ##
  Žrouti

  ### Seriál Žrouti: serEpilog

  Před 6 roky •
  257823 zhlédnutí
  Domácí zabijačka podle Roberta Mikluše. Chcete-li si pochutnat na vynikajícím guláši a tlačence s pistáciemi, stačí mít dobrého kamaráda profesionála a prase, kterého se chcete zbavit.

- ##
  FocusOn

  ### Převzetí Credit Suisse bankou UBS může mít nečekanou dohru. Výprodej eura

  Před 9 hodinami
  Víkendové převzetí Credit Suisse investiční bankou UBS přepisuje historii firemních dluhopisů. Došlo totiž k odepsání obrovské sumy dluhů Credit Suisse. Šestnáct miliard švýcarských franků není částka, nad kterou by finanční svět mohl mávnout rukou. Toto řešení-neřešení vyvolává značné obavy, ale i otázky, a to ohledně bezpečnosti investic do tohoto dluhu, vydaného jinými bankami.

- ##
  TN

  ### Síkela k plynu: Zimu jsme zvládli, vyhráno ale nemáme. Chystá se revoluční změna

  Před 11 hodinami
  Přes veškeré obavy Česko zvládlo zimu po energetické stránce bez větších obtíží, a navíc má nyní rekordní zásoby plynu, oznámili na úterní tiskové konferenci vicepremiér Vít Rakušan (STAN) a ministr průmyslu a obchodu Jozef Síkela (za STAN). Stále ale nemáme vyhráno a čeká nás ještě velká výzva. Síkela tak brzy představí novou strategickou koncepci, která zahrnuje i revoluční změnu, kterou má být komunitní energetika.

- ##
  Finance

  ### I z milionového příjmu může plynout nižší důchod než z minimální mzdy

  Před 22 hodinami
  Pro výpočet starobního důchodu není rozhodující, jaká částka byla zaplacena na dani z příjmů, ale odvody na sociální pojištění. V praxi lidé pracující za minimální mzdu zaplatí na sociální pojištění více než lidé s milionovým zdanitelným příjmem.

- ##
  Sport

  ### Vjalbeová o návratu Rusů: Podpis je zrada. Musíme stát za Putinem, s Ukrajinou neválčíme

  Před 7 hodinami
  Po mistrovství světa v klasickém lyžování v Planici se znovu začaly ozývat hlasy o povolení návratu ruských reprezentantů na mezinárodní scénu. Stejné úvahy už navzdory stále pokračující ruské invazi na Ukrajinu naznačil i Mezinárodní olympijský výbor (MOV), byť za určitých podmínek. Šéfka ruského lyžování Jelena Vjalbeová však jakékoliv podmínky rázně odmítá, trvá na návratu se vší parádou.

- ##
  Život v Česku

  ### Mluvil jste arogantně. Nechlapsky lžete, káral Jakub Železný strážníka. Teď se omluvil. Situaci okomentoval Andor Šándor

  Před 8 hodinami
  Moderátor Jakub Železný (49) se před pár měsíci dostal do konfliktu s muži zákona, když s nimi svérázně diskutoval o špatném parkování. Na stránkách městské policie bylo minulý týden uveřejněno video v anonymizované podobě, které celý incident zachycuje. Na internetu se v současnosti objevily informace, že má jít o známého moderátora. Pod tlakem okolností se následně v úterý Jakub Železný na Twitteru přiznal, že se jedná právě o něj, a za celou událost se omluvil. Pro ŽivotvČesku.cz se k situaci na dotaz vyjádřil politický komentátor Andor Šándor (65).

- ##
  Fonetech

  ### Bizarní zákon v praxi! V Německu nemohou řidiči za jízdy používat navigaci v telefonu, hrozí jim pokuta

  Před 16 hodinami
  Konec používání navigací v telefonu během jízdy autem? Vše tomu nasvědčuje! V Německu kvůli tomu padla první pokuta.

- ##
  Brněnská Drbna

  ### V Brně ženou do vězení ženu, která měsíce lidem brala nákupní vozíky

  Před 6 hodinami
  Přes půl roku si pracovníci brněnského supermarketu lámali hlavu nad tím, kam mizí z prodejny nákupní vozíky. Odpověď na záhadu přinesli nečekaně městští policisté, kteří se u garáží seznámili s šestapadesátiletou ženou, jež se nechtěně pochlubila početnou sbírkou.

- ##
  Žena-in

  ### S nejlepší kamarádkou máme stejně staré děti. Odlišný přístup k mateřství nás rozhádal, svěřuje se Anna

  Před 5 hodinami
  Eva s Annou byly nejlepšími kamarádkami už od základní školy, a když zjistily, že čekají miminka skoro ve stejnou dobu, byly nadšené. Těšily se na to, jak budou jezdit na procházky s kočárky a jak se jejich děti skamarádí. Jenže místo toho, aby je mateřství spojilo, rozdělilo je.

- ##
  Forum 24

  ### Tanky Abrams budou na Ukrajině bojovat dříve. Američané dodají stroje ze skladů

  Před 2 hodinami
  John Kirby, koordinátor strategické komunikace Národní bezpečnostní rady, oznámil, že USA pracují na urychlení dodávek moderních tanků na Ukrajinu. Aby proces netrval roky, dojde ke změně v typu ...

- ##
  Forum 24

  ### Prezident Pavel kontra Mračková Vildumetzová. Necouvejme, jde o demokracii

  Před 17 hodinami
  Poslankyně hnutí ANO paní Mračková Vildumetzová se v neděli v diskusním pořadu na CNN Prima News vyjádřila kriticky k tomu, jak vysvětlil na tiskové konferenci v minulém Petr Pavel své rozhodnutí ...

- ##
  Petr Lachnit
  na Seznam Médium

  ### Dvojí metr je příčinou rozhořčenosti davu

  Před 12 hodinami
  Tak nějak nám nespokojenost občanů postupně přerůstá v rozhořčení. Je dobré si začít všímat výrazných společných prvků této občanské nespokojenosti. Jednoznačně dominuje nesouhlas s úlohou, postoji a prací všech politických stran bez rozdílu.

- ##
  Babinet

  ### Šaty pro jaro 2023: Nosit se budou ikonické květiny i nezvyklá černá

  Před 1 dnem
  Šaty a jaro zkrátka patří neodmyslitelně k sobě. A jelikož astronomické jaro již oficiálně začalo, nastal nejvyšší čas si představit módní trendy pro toto období. Jaké šaty se během jara 2023 budou nosit nejčastěji?

- ##
  Jak nás vidí svět

  ### Moravský vrabec, špenát a br. knedlík. Co na to říká svět?

  Před 2 roky •
  497106 zhlédnutí

- ##
  České noviny

  ### Zpěvačka Jana Kratochvílová oslaví své 70. narozeniny koncertem v Lucerně

  Před 7 hodinami
  Zpěvačka Jana Kratochvílová oslaví své letošní 70. narozeniny, které připadly na 14. ledna, koncertem s mnoha hosty 10. listopadu v pražské Lucerně. Zlínská rodačka byla jednou z největších hvězd českého popu 70. a 80. let. Proslavily ji především hity Publikum tvé jsem já, Stín kapradiny nebo Milování za svítání. Mezi gratulanty bude například Michal Pavlíček, který se v roce 1980 výrazně podílel na jejím debutovém albu. Novináře o tom informovali pořadatelé koncertu.

- ##
  Magazín

  ### Antikoncepční metody našich praprababiček

  Před 15 hodinami
  Sexuální osvěta v 19. století a ještě na začátku 20. století se pokoušela dostat pod kontrolu pohlavní nemoci jako syfilis či kapavku, ale také neuvěřitelné množství nemanželských dětí. Jaké prostředky se tehdy doporučovaly?

- ##
  Hanácká Drbna

  ### Minuta ticha pro devítiletého Adama: život malého hokejisty vyhasl po autonehodě

  Před 1 dnem
  Velmi smutný začátek bude mít první domácí utkání Olomouce v sérii extraligového play-off proti Pardubicím. Hráči i diváci uctí památku devítiletého hokejisty Adama Koutného, jehož život vyhasl v neděli následkem autohavárie.

Skok před automaticky načítané články.

## Email Firemní e-mail zdarma

Přihlásit Založit nový účet

##
Reklama Koupit reklamu

## Služby

- Akce/Letáky
- Auto/Moto
- Bazar
- Deníky
- Dovolená
- Email Profi
- Filmy online
- Hry
- Jízdní řády
- Mapy
- Médium
- Mobilní aplikace
- Podcasty
- Pohádky
- Prohlížeč
- Rádio/Klasika
- Reality
- Recepty
- Slovník
- Volná místa
- Zboží/Magazín

### Počasí

Předpověď větru

- 7 °CVečer
- 6 °CV noci
- 16 °CZítra

Předpověď větru

## Seznam Médium

### Prasátko Peppa jen po 22. hodině. Proč cenzurovat dětský seriál?

V jednom díle oblíbeného dětského kresleného seriál Prasátko Peppa je jen okrajově zmíněno, že Peppina kamarádka má dvě mámy – lední medvědice. A v Maďarsku přišel zákaz vysílání během dne.

### Nejčastější příčiny bolesti kolene

### Prostituci nigerijských dívek v Itálii spoluřídí afričtí čarodějové juju

### Dvojí metr je příčinou rozhořčenosti davu

## Rádio

## Firmy

Přidat firmu

### Penzion U KOTLE

Horské penziony

- Web
- 604 352 457

Vítkovice

- Autobazary
- Autoservisy
- Bary
- Dovolená
- Erotika
- Hotely
- Jazykové školy
- Kadeřnictví
- Kosmetika
- Kuchyně
- Lázně
- Nábytek
- Okna
- Penziony
- Pneumatiky
- Pneuservisy
- Pojištění
- Půjčky
- Realitky
- Řemeslníci
- Stěhování
- Taxi
- Veterina
- Zámečnictví

## Horoskopy

Beran
Nyní máte přízeň planet pro pracovní sféru, takže se snažte využít každé šance, která se vám nabídne, abyste se posunuli opět o nějaký ten krok dál. Bude se vám líbit, že můžete uplatnit své nabyté zkušenosti a ukázat ostatním, jak moc jste dobří.
Celý horoskop »

## TV program

od 22:10 do 23:10 Moje místa (200)
od 21:35 do 23:09 Vlastníci
od 22:05 do 00:35 Vůně ženy
od 21:30 do 23:10 Mise Nový domov III
od 20:00 do 22:35 Pacific Rim: Útok na Zemi
od 21:35 do 22:45 7 pádů Honzy Dědka
od 22:00 do 23:15 Spartakus: Krev a písek (3)
od 21:55 do 23:10 Slunečná (51)
od 21:45 do 22:20 Taková byla 90. léta
Reklama